@@ -27,7 +27,7 @@ class SessionCancellation:
     """
     Represents a cancellation method which may be included in a session creation request.
     """
-    method: str
+    strategy: str
     options: Dict[str, object] = field(default_factory=dict)
 
 
