@@ -15,15 +15,12 @@ def serialize_match_config(config: MatchConfig) -> Dict:
     if config.match_function is not None:
         d["matchFunction"] = config.match_function
 
-    if config.selection_strategy is not None:
-        d["selectionStrategy"] = config.selection_strategy
+    if config.match_mode is not None:
+        d["matchMode"] = config.match_mode
 
     if config.threshold is not None:
         d["threshold"] = config.threshold
 
-    if config.match_mode is not None:
-        d["matchMode"] = config.match_mode
-
     return d
 
 
